@@ -23,7 +23,7 @@ sys.path.append(os.path.abspath('sphinxext'))
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.todo', 'preprocess']
+extensions = ['autodoc', 'sphinx.ext.todo', 'preprocess']
 
 # Todo configuration
 todo_include_todos = True
