@@ -64,6 +64,12 @@ class Touchtracer(FloatLayout):
                 pass
 
         ud['label'].pos = touch.pos
+        import time
+        t = int(time.time())
+        if t not in ud:
+            ud[t] = 1
+        else:
+            ud[t] += 1
         self.update_touch_label(ud['label'], touch)
 
     def on_touch_up(self, touch):
