@@ -219,6 +219,7 @@ from kivy.event import EventDispatcher
 from kivy.lang import Builder
 from kivy.resources import resource_find
 from kivy.utils import platform
+from kivy.uix.widget import Widget
 
 
 class App(EventDispatcher):
@@ -298,9 +299,11 @@ class App(EventDispatcher):
         If this method returns a widget (tree), it will be used as the root
         widget and added to the window.
 
-        :return: None or a root :class:`~kivy.uix.widget.Widget` instance
+        :return: None or a root :class:`~kivy.uix.widget.Widget` instance is no
+        self.root exist.
         '''
-        pass
+        if not self.root:
+            return Widget()
 
     def build_config(self, config):
         '''.. versionadded:: 1.0.7
@@ -422,7 +425,13 @@ class App(EventDispatcher):
         if filename is None:
             return config
         if exists(filename):
-            config.read(filename)
+            try:
+                config.read(filename)
+            except:
+                Logger.error('App: Corrupted config file, ignored.')
+                self.config = config = ConfigParser()
+                self.build_config(config)
+                pass
         else:
             config.filename = filename
             config.write()
@@ -598,7 +607,7 @@ class App(EventDispatcher):
 
     def _on_keyboard_settings(self, window, *largs):
         key = largs[0]
-        setting_key = 282 # F1
+        setting_key = 282  # F1
 
         # android hack, if settings key is pygame K_MENU
         if platform() == 'android':
@@ -612,4 +621,3 @@ class App(EventDispatcher):
             return True
         if key == 27:
             return self.close_settings()
-
