@@ -71,9 +71,9 @@ class PackageBuild(Command):
     def run(self):
         # Call this file and make a distributable .zip file that has our desired
         # folder structure
-        call(['python', 'setup.py', 'install', '--root', 'output/', '--install-lib',
-              '/', '--install-platlib', '/', '--install-data', '/%(extname)s/data',
-              'bdist', '--formats=zip'])
+        call(['python', 'setup.py', 'install', '--root', 'output/',
+            '--install-lib', '/', '--install-platlib', '/', '--install-data',
+            '/%(extname)s/data', 'bdist', '--formats=zip'])
         files = os.listdir('dist')
         if not os.path.isdir('kexfiles'):
             os.mkdir('kexfiles')
