@@ -11,8 +11,10 @@ FileChooser
 
 .. versionchanged:: 1.2.0
 
-    In chooser template, the `controller` is not a direct reference anymore, but a weak-reference.
-    You must update all the notation `root.controller.xxx` to `root.controller().xxx`.
+    In chooser template, the `controller` is not a direct reference anymore, but
+    a weak-reference.
+    You must update all the notation `root.controller.xxx` to
+    `root.controller().xxx`.
 
 '''
 
@@ -73,6 +75,10 @@ def alphanumeric_folders_first(files):
            sorted(f for f in files if not isdir(f))
 
 
+class ForceUnicodeError(Exception):
+    pass
+
+
 class FileChooserProgressBase(FloatLayout):
     '''Base for implementing a progress view. This view is used when too many
     entries need to be created, and are delayed over multiple frames.
@@ -213,7 +219,23 @@ class FileChooserController(FloatLayout):
 
     .. versionadded:: 1.2.0
 
-    :class:`~kivy.properties.ObjectProperty`, defaults to :class:`FileChooserProgress`
+    :class:`~kivy.properties.ObjectProperty`, defaults to
+    :class:`FileChooserProgress`
+    '''
+
+
+    file_encodings = ListProperty(['utf-8', 'latin1', 'cp1252'])
+    '''Possible encodings for decoding a filename to unicode. It might be
+    possible than user have a weird filename, undecodable without knowing it's
+    initial encoding. We have no other choice to guess it.
+
+    Please note that if you encounter an issue cause of a missing encodings
+    here, we'll be glad to add it in this list.
+
+    .. versionadded:: 1.3.0
+
+    :class:`~kivy.properties.ListProperty`, defaults to ['utf-8', 'latin1',
+    'cp1252']
     '''
 
     def __init__(self, **kwargs):
@@ -279,7 +301,8 @@ class FileChooserController(FloatLayout):
         '''(internal) This method must be called by the template when an entry
         is touched by the user.
         '''
-        if 'button' in touch.profile and touch.button in ('scrollup', 'scrolldown'):
+        if 'button' in touch.profile and touch.button in (
+            'scrollup', 'scrolldown'):
             return False
         if self.multiselect:
             if isdir(entry.path) and touch.is_double_tap:
@@ -302,7 +325,8 @@ class FileChooserController(FloatLayout):
 
         .. versionadded:: 1.1.0
         '''
-        if 'button' in touch.profile and touch.button in ('scrollup', 'scrolldown'):
+        if 'button' in touch.profile and touch.button in (
+            'scrollup', 'scrolldown'):
             return False
         if not self.multiselect:
             if isdir(entry.path) and not self.dirselect:
@@ -322,6 +346,7 @@ class FileChooserController(FloatLayout):
             try:
                 path = entry.path.decode('utf-8')
             except UnicodeEncodeError:
+                path = entry.path
                 pass
             listdir(path)
         except OSError:
@@ -423,7 +448,8 @@ class FileChooserController(FloatLayout):
         return False
 
     def cancel(self, *largs):
-        '''Cancel any background action started by filechooser, like loading a new directory.
+        '''Cancel any background action started by filechooser, like loading a
+        new directory.
 
         .. versionadded:: 1.2.0
         '''
@@ -470,15 +496,15 @@ class FileChooserController(FloatLayout):
             elif platform in ('macosx', 'linux', 'android', 'ios'):
                 is_root = normpath(expanduser(path)) == sep
             else:
-                # Unknown file system; Just always add the .. entry but also log
+                # Unknown fs, just always add the .. entry but also log
                 Logger.warning('Filechooser: Unsupported OS: %r' % platform)
                 is_root = False
         # generate an entries to go back to previous
         if not is_root and not have_parent:
             back = '..' + sep
             pardir = Builder.template(self._ENTRY_TEMPLATE, **dict(name=back,
-                size='', path=back, controller=ref(self), isdir=True, parent=None,
-                sep=sep, get_nice_size=lambda: ''))
+                size='', path=back, controller=ref(self), isdir=True,
+                parent=None, sep=sep, get_nice_size=lambda: ''))
             yield 0, 1, pardir
 
         # generate all the entries for files
@@ -489,14 +515,22 @@ class FileChooserController(FloatLayout):
             Logger.exception('Unable to open directory <%s>' % self.path)
 
     def _add_files(self, path, parent=None):
-        path = expanduser(path)
+        force_unicode = self._force_unicode
         # Make sure we're using unicode in case of non-ascii chars in filenames.
         # listdir() returns unicode if you pass it unicode.
         try:
-            path = path.decode('utf-8')
-        except UnicodeEncodeError:
+            path = expanduser(path)
+            path = force_unicode(path)
+        except ForceUnicodeError:
             pass
-        files = listdir(path)
+
+        files = []
+        fappend = files.append
+        for fn in listdir(path):
+            try:
+                fappend(force_unicode(fn))
+            except ForceUnicodeError:
+                pass
         # In the following, use fully qualified filenames
         files = [normpath(join(path, f)) for f in files]
         # Apply filename filters
@@ -524,6 +558,21 @@ class FileChooserController(FloatLayout):
             entry = Builder.template(self._ENTRY_TEMPLATE, **ctx)
             yield index, total, entry
 
+    def _force_unicode(self, s):
+        # the idea is, whatever is the filename, unicode or str, even if the str
+        # can't be directly returned as a unicode, return something.
+        if type(s) is unicode:
+            return s
+        encodings = self.file_encodings
+        for encoding in encodings:
+            try:
+                return s.decode(encoding, 'strict')
+            except UnicodeDecodeError:
+                pass
+            except UnicodeEncodeError:
+                pass
+        raise ForceUnicodeError('Unable to decode %r' % s)
+
     def entry_subselect(self, entry):
         if not isdir(entry.path):
             return
