@@ -2,11 +2,22 @@
 Stack Layout
 ============
 
+.. only:: html
+
+    .. image:: images/stacklayout.gif
+        :align: right
+
+.. only:: latex
+
+    .. image:: images/stacklayout.png
+        :align: right
+
 .. versionadded:: 1.0.5
 
 :class:`StackLayout` arranges children vertically or horizontally, as many
 as the layout can fit.
 
+
 .. warning:
 
     This is experimental and subject to change as long as this warning notice is
@@ -111,6 +122,8 @@ class StackLayout(Layout):
             for c in reversed(self.children):
                 if c.size_hint_x:
                     c.width = c.size_hint_x * (selfw - padding2)
+                if c.size_hint_y:
+                    c.height = c.size_hint_y * (selfh - padding2)
 
                 # is the widget fit in the line ?
                 if lw - c.width >= 0:
@@ -145,6 +158,8 @@ class StackLayout(Layout):
             lw = 0
             lh = self.height - padding2
             for c in reversed(self.children):
+                if c.size_hint_x:
+                    c.width = c.size_hint_x * (selfw - padding2)
                 if c.size_hint_y:
                     c.height = c.size_hint_y * (selfh - padding2)
 
