@@ -93,7 +93,9 @@ Shift + <dir>   Start a text selection. Dir can be Up, Down, Left, Right
 Control + c     Copy selection
 Control + x     Cut selection
 Control + p     Paste selection
-control + a     Select all the content
+Control + a     Select all the content
+Control + z     undo
+Control + r     redo
 =============== ========================================================
 
 '''
@@ -169,6 +171,7 @@ class TextInput(Widget):
         self._label_cached = None
         self._line_options = None
         self._keyboard = None
+        self.reset_undo()
         self.interesting_keys = {
             8: 'backspace',
             13: 'enter',
@@ -256,22 +259,93 @@ class TextInput(Widget):
             i = ni
         return index, row
 
-    def insert_text(self, substring):
+    def insert_text(self, substring, from_undo = False):
         '''Insert new text on the current cursor position
         '''
+        if self.readonly:
+            return
         cc, cr = self.cursor
-        ci = self.cursor_index()
+        sci = self.cursor_index
+        ci = sci()
         text = self._lines[cr]
+        len_str = len(substring)
         new_text = text[:cc] + substring + text[cc:]
         self._set_line_text(cr, new_text)
-        if len(substring) > 1 or substring == '\n':
+        if len_str > 1 or substring == '\n':
             # Avoid refreshing text on every keystroke.
             # Allows for faster typing of text when the amount of text in
             # TextInput gets large.
             self._trigger_refresh_text()
-        self.cursor = self.get_cursor_from_index(ci + len(substring))
+        #reset cursor
+        self.cursor = cursor = self.get_cursor_from_index(ci + len_str)
+        #handle undo and redo
+        self._set_unredo_insert(cc, cr, ci, sci, substring, cursor, from_undo)
 
-    def do_backspace(self):
+    def _set_unredo_insert(self, cc, cr, ci, sci, substring, cursor, from_undo):
+        #handle undo and redo
+        if from_undo:
+            return
+        count = substring.count('\n')
+        if substring == '\n':
+            cursor = 0, cursor[1] + 1
+        elif count > 0:
+            cursor = cursor[0], cursor[1] + count
+
+        self._undo.append({'undo_command': \
+            'self.cursor = (%i, %i)\n' %(cursor[0], cursor[1]) +\
+            'self.selection_from = %i\nself.selection_to = %i\n' %(ci, sci())+
+            'self._selection = True\n'+\
+            'self.delete_selection(True)\n',\
+            'redo_command': \
+            'self.cursor = (%i, %i)\nself.insert_text(u\'%s\', True)'\
+            %(cc, cr, substring.replace('\n', '\\n').replace('\'', '\\\''))})
+        #reset redo when undo is appended to
+        self._redo = []
+
+    def reset_undo(self):
+        '''Reset undo and redo lists from memory
+
+        .. versionadded:: 1.3.0
+
+        '''
+        self._redo = self._undo = []
+
+    def do_redo(self):
+        '''Do redo operation
+
+        .. versionadded:: 1.3.0
+
+        This action re-does any command that has been un-done by do_undo/ctrl+z.
+        This function is automaticlly called when `ctrl+r` keys
+        are pressed.
+        '''
+        try:
+            x_item = self._redo.pop()
+            exec(x_item['redo_command'])
+            self._undo.append(x_item)
+        except IndexError:
+            # reached at top of undo list
+            pass
+
+    def do_undo(self):
+        '''Do undo operation
+
+        .. versionadded:: 1.3.0
+
+        This action un-does any edits that have been made since the last
+        call to reset_undo().
+        This function is automatically called when `ctrl+z` keys
+        are pressed.
+        '''
+        try:
+            x_item = self._undo.pop()
+            exec(x_item['undo_command'])
+            self._redo.append(x_item)
+        except IndexError:
+            # reached at top of undo list
+            pass
+
+    def do_backspace(self, from_undo = False):
         '''Do backspace operation from the current cursor position.
         This action might do lot of things like:
 
@@ -280,6 +354,8 @@ class TextInput(Widget):
             - do nothing, if we are at the start.
 
         '''
+        if self.readonly:
+            return
         cc, cr = self.cursor
         text = self._lines[cr]
         cursor_index = self.cursor_index()
@@ -289,8 +365,10 @@ class TextInput(Widget):
             text_last_line = self._lines[cr - 1]
             self._set_line_text(cr - 1, text_last_line + text)
             self._delete_line(cr)
+            substring = '\n'
         else:
             #ch = text[cc-1]
+            substring = text[cc-1]
             new_text = text[:cc-1] + text[cc:]
             self._set_line_text(cr, new_text)
 
@@ -298,7 +376,24 @@ class TextInput(Widget):
         # plus removing it leads to a large improvement in editing text
         # where large..ish text is involved.
         #self._refresh_text_from_property()
-        self.cursor = self.get_cursor_from_index(cursor_index - 1)
+        self.cursor = cursor = self.get_cursor_from_index(cursor_index - 1)
+        #handle undo and redo
+        self._set_undo_redo_bkspc(cc, cr, cursor, substring, from_undo)
+
+    def _set_undo_redo_bkspc(self, cc, cr, cursor, substring, from_undo):
+        #handle undo and redo for backspace
+        if from_undo:
+            return
+
+        self._undo.append({'undo_command': \
+            'self.cursor = (%i, %i)\n' %(cursor[0], cursor[1]) +\
+            'self.insert_text(u\'%s\', True)'\
+            %(substring.replace('\n', '\\n').replace('\'', '\\\'')),
+            'redo_command': \
+            'self.cursor = (%i, %i)\n' %(cc, cr)+\
+            'self.do_backspace(True)'})
+        #reset redo when undo is appended to
+        self._redo = []
 
     def do_cursor_movement(self, action):
         '''Move the cursor relative to it's current position.
@@ -372,11 +467,16 @@ class TextInput(Widget):
         self._selection_touch = None
         self._trigger_update_graphics()
 
-    def delete_selection(self):
+    def delete_selection(self, from_undo = False):
         '''Delete the current text selection (if any)
         '''
+        if self.readonly:
+            return
         scrl_x = self.scroll_x
         scrl_y = self.scroll_y
+        cc, cr = self.cursor
+        sci = self.cursor_index
+        ci = sci()
         if not self._selection:
             return
         v = self.text
@@ -385,11 +485,31 @@ class TextInput(Widget):
             a, b = b, a
         text = v[:a] + v[b:]
         self.text = text
-        self.cursor = self.get_cursor_from_index(a)
+        text = v[a:b]
+        self.cursor = cursor = self.get_cursor_from_index(a)
         self.scroll_x = scrl_x
         self.scroll_y = scrl_y
+        #handle undo and redo
+        self._set_unredo_delsel(cc, cr, a, b, cursor, text, from_undo)
         self.cancel_selection()
 
+    def _set_unredo_delsel(self, cc, cr, ci, sci, cursor, substring, from_undo):
+        #handle undo and redo for backspace
+        if from_undo:
+            return
+
+        self._undo.append({'undo_command': \
+            'self.cursor = (%i, %i)\n' %(cursor[0], cursor[1]) +\
+            'self.insert_text(u\'%s\', True)'\
+            %(substring.replace('\n', '\\n').replace('\'', '\\\'')),
+            'redo_command': \
+            'self.selection_from = %i\nself.selection_to = %i\n' %(ci, sci)+
+            'self._selection = True\n'+\
+            'self.delete_selection(True)\n'+\
+            'self.cursor = (%i, %i)\n' %(cc, cr)})
+        #reset redo when undo is appended to
+        self._redo = []
+
     def _update_selection(self, finished=False):
         '''Update selection text and order of from/to if finished is True.
         Can be called multiple times until finished=True.
@@ -461,15 +581,20 @@ class TextInput(Widget):
             if self.selection_to != self.selection_from:
                 self._show_cut_copy_paste(touch.pos, win)
             else:
-                win.remove_widget(self._bubble)
+                self._hide_cut_copy_paste(win)
             return True
 
+    def _hide_cut_copy_paste(self, win):
+        bubble = self._bubble
+        if bubble is not None:
+            win.remove_widget(bubble)
+
     def _show_cut_copy_paste(self, pos, win, parent_changed = False, *l):
         # Show a bubble with cut copy and paste buttons
         bubble = self._bubble
         if bubble is None:
             self._bubble = bubble = TextInputCutCopyPaste(textinput=self)
-            self.bind(parent = partial(self._show_cut_copy_paste,
+            self.bind(parent=partial(self._show_cut_copy_paste,
                 pos, win, True))
         else:
             win.remove_widget(bubble)
@@ -550,13 +675,19 @@ class TextInput(Widget):
             keyboard.release()
             self.cancel_selection()
             Clock.unschedule(self._do_blink_cursor)
+            self._hide_cut_copy_paste(win)
             self._win = None
 
+    def on_readonly(self, instance, value):
+        if not value:
+            self.focus = False
+
     def _ensure_clipboard(self):
         global Clipboard
-        if Clipboard is not None:
+        if hasattr(self, '_clip_mime_type'):
             return
-        from kivy.core.clipboard import Clipboard
+        if Clipboard is None:
+            from kivy.core.clipboard import Clipboard
         _platform = platform()
         if _platform == 'win':
             self._clip_mime_type = 'text/plain;charset=utf-8'
@@ -591,7 +722,9 @@ class TextInput(Widget):
 
         data = Clipboard.get(mime_type)
         if data is not None:
-            data = data.decode(self._encoding, 'ignore')
+            # decode only if we don't have unicode
+            if type(data) is not unicode:
+                data = data.decode(self._encoding, 'ignore')
             # remove null strings mostly a windows issue
             data = data.replace('\x00', '')
             self.delete_selection()
@@ -867,9 +1000,35 @@ class TextInput(Widget):
         kw = self._get_line_options()
         cid = '%s\0%s' % (ntext, str(kw))
         texture = Cache.get('textinput.label', cid)
+
         if not texture:
-            label = Label(text=ntext, **kw)
-            label.refresh()
+            # FIXME right now, we can't render very long line...
+            # if we move on "VBO" version as fallback, we won't need to do this.
+            # try to found the maximum text we can handle
+            label = None
+            label_len = len(ntext)
+            ld = None
+            while True:
+                try:
+                    label = Label(text=ntext[:label_len], **kw)
+                    label.refresh()
+                    if ld is not None and ld > 2:
+                        ld = int(ld / 2)
+                        label_len += ld
+                    else:
+                        break
+                except:
+                    # exception happen when we tried to render the text
+                    # reduce it...
+                    if ld is None:
+                        ld = len(ntext)
+                    ld = int(ld / 2)
+                    if ld < 2 and label_len:
+                        label_len -= 1
+                    label_len -= ld
+                    continue
+
+            # ok, we found it.
             texture = label.texture
             Cache.append('textinput.label', cid, texture)
         return texture
@@ -998,6 +1157,10 @@ class TextInput(Widget):
                     self.selection_from = 0
                     self.selection_to = len(self.text)
                     self._update_selection(True)
+                elif key == ord('z'): # undo
+                    self.do_undo()
+                elif key == ord('r'): # redo
+                    self.do_redo()
             else:
                 if self._selection:
                     self.delete_selection()
@@ -1030,6 +1193,15 @@ class TextInput(Widget):
 
     _lines = ListProperty([])
 
+    readonly = BooleanProperty(False)
+    '''If True, the user will not be able to change the content of a textinput.
+
+    .. versionadded:: 1.3.0
+
+    :data:`readonly` is a :class:`~kivy.properties.BooleanProperty`, default to
+    False
+    '''
+
     multiline = BooleanProperty(True)
     '''If True, the widget will be able show multiple lines of text. If false,
     "enter" action will defocus the textinput instead of adding a new line.
